//
//  MoPubNetwork.m
//  SampleApp
//
//  Created by Pokkt on 10/20/15.
//  Copyright © 2015 Pokkt. All rights reserved.
//

#import "MoPubNetwork.h"
#import "MoPub.h"
#import "MPRewardedVideo.h"
#import "AppDelegate.h"
#import "PokktNetworkDelegate.h"
#import "PokktManager.h"


@implementation MoPubNetwork


@synthesize networkName;

NetworkModel *network;
UIViewController *playerVC;
static NSString *unitID;

static NSString *networkType = @"MoPub";

- (void)initNetwork:(PokktConfig *)pokktConfig networkModel:(NetworkModel *)customData
presentingViewController:(UIViewController *)viewController
{
    NSLog(@"%@ is initialised", networkType);

    self.pokktConfig = pokktConfig;
    playerVC = viewController;
    unitID =[customData.customData objectForKey:@"AdUnitID"];
    [[MoPub sharedInstance] initializeRewardedVideoWithGlobalMediationSettings:@[] delegate:self];
    self.isVideoCached = NO;
    self.isTimedout = NO;
    
}

- (void)cacheVideo
{
    if (self.isVideoCached)
    {
        NSLog(@"%@ video cached previously", networkType);

        self.isVideoCached = NO;
        [PokktNetworkDelegate didFinishedVideoDownload:self.pokktConfig networkModel:network rewardValue:0 downLoadTime:@""];
    }
    else
    {
        NSLog(@"%@ video caching started", networkType);

        [MPRewardedVideo loadRewardedVideoAdWithAdUnitID:unitID withMediationSettings:@[]];
        self.isTimedout = NO;
        int cacheTimeoutInterval = [PokktManager getCachingTimeoutDuration:network];
        self.cacheTimer = [NSTimer scheduledTimerWithTimeInterval:cacheTimeoutInterval target:self selector:@selector(updateTimer) userInfo:nil repeats:NO];
        
    }
    
}

- (void)playVideo
{
    if ([MPRewardedVideo hasAdAvailableForAdUnitID:unitID])
    {
        NSLog(@"%@ play video called", networkType);

        [MPRewardedVideo presentRewardedVideoAdForAdUnitID:unitID fromViewController:playerVC];
    }
    
}

- (void)updateTimer
{
    if (self.cacheTimer)
    {
        NSLog(@"%@ video caching timed out", networkType);

        [self.cacheTimer invalidate];
        self.cacheTimer = nil;
        self.isTimedout = YES;
        
        [PokktNetworkDelegate didFailedVideoDownload:self.pokktConfig networkModel:network errorMessage:@"timed out"];
    }
}


- (void)rewardedVideoAdDidLoadForAdUnitID:(NSString *)adUnitID
{
    if (self.isTimedout)
    {
        NSLog(@"%@ video caching successful after timeout", networkType);

        self.isVideoCached = YES;
    }
    else
    {
        self.isVideoCached = NO;

        NSLog(@"%@ video caching successful before timeout", networkType);

        [self.cacheTimer invalidate];
        self.cacheTimer = nil;
        
        [PokktNetworkDelegate didFinishedVideoDownload:self.pokktConfig networkModel:network rewardValue:0 downLoadTime:@""];
    }
}

- (void)rewardedVideoAdDidFailToLoadForAdUnitID:(NSString *)adUnitID error:(NSError *)error
{
    self.isVideoCached = NO;

    if (self.isTimedout)
    {
        NSLog(@"%@ video caching failed after timeout", networkType);

    }
    else
    {
        NSLog(@"%@ video caching failed before timeout", networkType);

        [self.cacheTimer invalidate];
        self.cacheTimer = nil;
        
        [PokktNetworkDelegate didFailedVideoDownload:self.pokktConfig networkModel:network errorMessage:error.description];
    }
    
}

- (void)rewardedVideoAdShouldRewardForAdUnitID:(NSString *)adUnitID reward:(MPRewardedVideoReward *)reward
{
    [PokktNetworkDelegate onVideoGratified:self.pokktConfig networkModel:network rewardPoint:reward.amount.floatValue];
}

- (void)rewardedVideoAdDidDisappearForAdUnitID:(NSString *)adUnitID
{
    [PokktNetworkDelegate onVideoCompleted:self.pokktConfig networkModel:network];
    [PokktNetworkDelegate onVideoClosed:self.pokktConfig networkModel:network];
}
@end
